/*
 * DemosceneMusic - DefaultUser.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.data;

import java.io.UnsupportedEncodingException;
import java.util.Collection;

import net.pterodactylus.util.crypto.MessageDigestHasher;
import net.pterodactylus.util.number.Hex;
import net.pterodactylus.util.object.Default;

/**
 * Default implementation of a user data container.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class DefaultUser extends DefaultBase implements User {

	/**
	 * Creates a new user data container.
	 *
	 * @param id
	 *            The ID of the user
	 */
	public DefaultUser(String id) {
		super(id);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getName() {
		return getValue("name", String.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public User setName(String name) {
		getValue("name", String.class).set(name);
		return this;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public User setPassword(String password) {
		try {
			getValue("password", String.class).set(Hex.toHex(MessageDigestHasher.getSHA256Hasher().hash(password.getBytes("UTF-8"))));
			return this;
		} catch (UnsupportedEncodingException uee1) {
			throw new RuntimeException("VM does not support UTF-8.", uee1);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public User setPasswordHash(String passwordHash) {
		getValue("password", String.class).set(passwordHash);
		return this;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean verifyPassword(String password) {
		try {
			return getValue("password", String.class).get().equalsIgnoreCase(Hex.toHex(MessageDigestHasher.getSHA256Hasher().hash(password.getBytes("UTF-8"))));
		} catch (UnsupportedEncodingException uee1) {
			throw new RuntimeException("VM does not support UTF-8.", uee1);
		}
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int getLevel() {
		return Default.forNull(getValue("level", Integer.class).get(), 0);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public User setLevel(int level) {
		getValue("level", Integer.class).set(level);
		return this;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	@SuppressWarnings("unchecked")
	public Collection<String> getOpenIds() {
		return getValue("openIds", Collection.class).get();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public User setOpenIds(Collection<String> openIds) {
		getValue("openIds", Collection.class).set(openIds);
		return this;
	}

}
