/*
 * DemosceneMusic - EditPartyPage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page.admin;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.demoscenemusic.data.Party;
import net.pterodactylus.demoscenemusic.page.ServletRequest;
import net.pterodactylus.util.database.DatabaseException;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContext;
import net.pterodactylus.util.template.TemplateContextFactory;
import net.pterodactylus.util.web.Method;
import net.pterodactylus.util.web.RedirectException;

/**
 * Page that lets the user edit a party.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class EditPartyPage extends AdminBasePage {

	/**
	 * Creates a new “edit party” page.
	 *
	 * @param core
	 *            The core
	 * @param templateContextFactory
	 *            The template context factory
	 * @param template
	 *            The template to render
	 */
	public EditPartyPage(Core core, TemplateContextFactory templateContextFactory, Template template) {
		super(core, templateContextFactory, template, "admin.edit-artist");
	}

	//
	// BASEPAGE METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void processTemplate(TemplateContext templateContext, ServletRequest request) throws RedirectException {
		super.processTemplate(templateContext, request);
		String id = request.getServletRequest().getParameter("id");
		/* TODO - check for null. */
		Party party;
		try {
			party = getCore().getDataManager().getPartyById(id);
			/* TODO - check for null. */
			templateContext.set("party", party);
			if (request.getMethod() == Method.POST) {
				String name = request.getServletRequest().getParameter("name");
				party.setName(name);

				/* process property changes. */
				processProperties(request, party);

				getCore().getDataManager().saveParty(party);
				throw new RedirectException("admin.edit-party?id=" + party.getId());
			}
		} catch (DatabaseException de1) {
			throw new RuntimeException("Could not load artist.", de1);
		}
	}

}
